'-------------- Device Params -----------------------
Params 
	DRV.OPMODE = 2'position operation mode
	DRV.CMDSOURCE = 5'command source = AKD BASIC TG
	UNIT.PROTARY = 4'16 bit position units, 65536 counts/rev
	UNIT.VROTARY = 0'velocity units = rpm
	UNIT.ACCROTARY = 0'acceleration units = rpm/sec
End Params

'-------------- Define (dim) Global Variables --------
const MC = 10000'master counts in total cycle 
const NPOINTS = 501'number of points in cam profile 
const pi = 3.1415926535
const k = 0.69314718 / 100
const w = 1 / (7.5 * pi)

'-------------- Main Program -------------------------
Main 
	
	FB2.ENCRES = 4000'counts/rev for virtual master
	EXTENCODER.POSMODULO = MC' Set master modulo value
	PL.MODPEN = 1'Enable slave modulo
	PL.MODP2 = 65536'Set slave modulo value
	Cam.Activate = 0' Turn off any active cams
	Cam.Master = 1' Master = virtual encoder only
	CamVM.Position = 0' Clear the virtual master position
	CamVm.Dir = 0'set direction of virtual master
	CamVM.Freq = 1000' set virtual master speed
	MOVE.POSCOMMAND = 0
	
	'Generate a cam that does exponentially-damped sinusoidal 
	'motion and activate it. Please note that since we are computing 
	'500 points of slave profile here several seconds will elapse 
	'during the calculation of the cam table. 	
	call CamCreate_2
	call ActivateCam_2
	CAMVM.GOVEL 'virtual master to run at CAMVM.FREQ
	'While 1 : Wend
End Main

'-------------- Subroutines and Functions ------------
sub CamCreate_2'This code creates a cam whose profile is an exponentially damped sine wave. 
	dim m, s as float 
	dim i as integer 
	CAM.CREATE (2, 501)
		for i = 0 to NPOINTS-1
			m = i * (MC / (NPOINTS-1))'master position    
			s = (1 / exp (1.5 * k * i)) * sin (2 * pi * w * i)'computed slave position   
			CAM.ADDPOINT(m, 65536 * s)
		next i
	end CAM.CREATE
end sub

sub ActivateCam_2
	DRV.SWENABLE = 0' Need to disable the drive before changing positions
	DRV.SWENABLE = 1' Enable drive
	Cam.Activate = 2' Start the cam
end sub

'-------------- Interrupt Routines -------------------
